StandardBizStep

Enum StandardBizStep 

#[non_exhaustive]
pub enum StandardBizStep {
Show 30 variants Accepting, Arriving, Assembling, Collecting, Commissioning, Decommissioning, Departing, Destroying, Disassembling, EnteringExiting, Holding, Inspecting, Installing, Killing, Loading, Other, Packing, Picking, Receiving, Removing, Repackaging, Repairing, Reselling, Shipping, Stocking, Storing, Transporting, Unloading, Unpacking, Voiding,
}
Standard business step (bizStep) values as defined by GS1 CBV.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Accepting

accepting



Arriving

arriving



Assembling

assembling



Collecting

collecting



Commissioning

commissioning



Decommissioning

decommissioning



Departing

departing



Destroying

destroying



Disassembling

disassembling



EnteringExiting

entering_exiting



Holding

holding



Inspecting

inspecting



Installing

installing



Killing

killing



Loading

loading



Other

other



Packing

packing



Picking

picking



Receiving

receiving



Removing

removing



Repackaging

repackaging



Repairing

repairing



Reselling

reselling



Shipping

shipping



Stocking

stocking



Storing

storing



Transporting

transporting



Unloading

unloading



Unpacking

unpacking



Voiding

voiding