pub struct SensorMetadata {
pub time: Option<DateTime<Utc>>,
pub device_id: Option<String>,
pub device_metadata_uri: Option<String>,
pub raw_data_uri: Option<String>,
pub data_content_uri: Option<String>,
pub biz_rules_uri: Option<String>,
}Expand description
Metadata about a sensor device or sensor data source.
Fields
time: Option<DateTime<Utc>>Time when the sensor metadata was generated
device_id: Option<String>Device identifier
device_metadata_uri: Option<String>URI pointing to device metadata details
raw_data_uri: Option<String>URI pointing to raw sensor data
data_content_uri: Option<String>URI pointing to parsed data content
biz_rules_uri: Option<String>URI pointing to business logic rules applied to the sensor